/*  MaViLla: Marcador y Visualizador de Llamadas
 *
 *  Copyright (C) 2011  Area de Servicios Telematicos
 *			CSIRC
 *			Universidad de Granada
 *			telematica@ugr.es
 *  
 *  Version: 1.1
 *  Last Modified: 30 May 2011
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef EDICION_H
#define EDICION_H

#include <QDialog>
#include <QTableView>

namespace Ui {
    class Edicion;
}

class Edicion : public QDialog
{
    Q_OBJECT

private slots:

    /**
    @brief Edicion de datos

    Verifica que los datos modificados sean correctos y guarda los cambios.
    */
    void editarEntrada();

public:

    /**
    @brief Constructor por defecto
    @param t Tabla desde la cual obtener los datos
    @param parent widget Padre
    */
    explicit Edicion(QTableView *t, QWidget *parent = 0);

    /**
    @brief Destructor por defecto

    Libera la memoria reservada
    */
    ~Edicion();

    /**
    @brief Obtencion de datos
    @param fila Fila seleccionada para editar

    Obtiene los valores de la fila que se quiere modificar y los muestra en
    una ventana desde la cual podemos editarlos
    */
    void obtenerEntrada(int fila);

private:
    Ui::Edicion *ui;
    QTableView *tableview; // Tabla de datos
    QString marca_imp; // Marca de importante
    int fila;

    /**
    @brief Comprobacion de errores
    @return true si hay algun error, false en otro caso

    Realiza una simple comprobacion de errores para ver que los campos son correctos
    */
    bool hayErrores(QString &err);
};

#endif // EDICION_H
