/*  MaViLla: Marcador y Visualizador de Llamadas
 *
 *  Copyright (C) 2011  Area de Servicios Telematicos
 *			CSIRC
 *			Universidad de Granada
 *			telematica@ugr.es
 *  
 *  Version: 1.1
 *  Last Modified: 30 May 2011
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef ENTRADA_H
#define ENTRADA_H

#include <QDialog>
#include <QTableView>


namespace Ui {
    class Entrada;
}

class Entrada : public QDialog
{
    Q_OBJECT

private slots:

    /**
    @brief Creacion de entrada en agenda

    Crea una nueva entrada en nuestra tabla e inserta los datos que hemos introducido.
    */
    void addNuevaEntrada();

public:

    /**
    @brief Constructor por defecto
    @param t Tabla en la cual insertar los datos
    @param parent widget Padre
    */
    Entrada(QTableView *t, QWidget *parent = 0);

    /**
    @brief Destructor por defecto

    Libera la memoria reservada
    */
    ~Entrada();

    /**
    @brief Resetea los campos de texto 
    @param nombre Contiene el nombre del contacto
    @param telefono Contiene el telefono del contacto
    @param imp Especifica si el contacto es importante o no
	
    Cambia la informacion que hubiera en los campos de texto, para limpiar el formulario basta con dejar 
	los campos por defecto.
    */
    void resetearEntrada(const QString &nombre="",const QString &telefono="", const bool &imp = false);

private:
    Ui::Entrada *ui;
    QTableView *tableview; // Tabla de datos
    QString marca_imp; // Marca de importante

    /**
    @brief Comprobacion de errores
    @return true si hay algun error, false en otro caso

    Realiza una simple comprobacion de errores para ver que los campos son correctos
    */
    bool hayErrores(QString &err);
};

#endif // ENTRADA_H
