/*  MaViLla: Marcador y Visualizador de Llamadas
 *
 *  Copyright (C) 2011  Area de Servicios Telematicos
 *			CSIRC
 *			Universidad de Granada
 *			telematica@ugr.es
 *  
 *  Version: 1.1
 *  Last Modified: 30 May 2011
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "principal.h"
#include "ui_principal.h"
#include <QMessageBox>

#include <QtGui>


Principal::Principal(QString dirpath, QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::Principal), // Objeto grafico
    path(dirpath), // Directorio de la aplicacion
    image1(dirpath + "img/ugr.png",this), // imagen ugr
    image2(dirpath + "img/csirc.png",this), // imagen csirc
    marca_imp("*"), // marca importante
    cadena_mostrar("MostrarSoloContactos") // Opcion de solo mostrar los contactos que llaman
{
    ui->setupUi(this);
    // si hacemos doble click sobre algun contacto, se le llamara
    connect(ui->tableView,SIGNAL(doubleClicked(QModelIndex)),this,SLOT(llamar()));
    // Titulo
    setWindowTitle(tr("Marcador y Visualizador de Llamadas"));
    // Iconos
    icon = QIcon(path + "img/mavilla.png");
    this->setWindowIcon(icon);
    // Crear las acciones y los menus
    crearAcciones();
    crearMenus();
    crearBarraHerramientas();
    crearMenusContextuales();
    // Creo los dialogos de la aplicacion
    llam_sal = new Llamada_saliente(this);
    erro = new Errores(this);
    ent = new Entrada(ui->tableView,this);
    edi = new Edicion(ui->tableView,this);
    reg_llam = new Registro_llamadas(ent,path,this);
    // Creo el socket y lo enlazo al puerto
    crearServidor(puerto);
    // Icono en area de notificacion
    crearMenuNotificacion();
    // Aadimos las imagenes
    ui->horizontalLayout->addWidget(&image1);
    ui->horizontalLayout->addWidget(&image2);
    // Cargamos el panel central
    crearAgenda();
    // Quitando los botones de maximizar y minimizar
    Qt::WindowFlags flags = Qt::Window | Qt::WindowCloseButtonHint;
    this->setWindowFlags(flags);
    // Se indica que no se ha hecho ninguna edicion
    as_editado = false;
    connect(modelo,SIGNAL(dataChanged(QModelIndex,QModelIndex)),this,SLOT(datosEditados(QModelIndex,QModelIndex)));
}


void Principal::procesarEntrada()
{
    // Obtengo los datos
    QHostAddress sender;
    QString mensaje = "";
    // Mientras haya datagramas que leer
    while (udpSocket->hasPendingDatagrams()) {
            QByteArray datagram;
            datagram.resize(udpSocket->pendingDatagramSize());
            udpSocket->readDatagram(datagram.data(), datagram.size(),&sender);
            mensaje = datagram.data();
        }
    // Proceso los datos
    QString nombre = "", telefono = "", ip_send = sender.toString();
    bool importante = false, encontrado = false;
    // Troceo el mensaje 
    QStringList lista;
    lista = mensaje.split("\n");
    // Si el mensaje contiene informacion
    if( lista.count() > 1)
    	if(lista[0].trimmed() == cab_mensaje || cab_mensaje == "") // Si la cabecera de mensaje coincide con la especificada o esta vacia
        if(ip_send.left(ip.length()) == ip || ip == "") // Si la ip de mensaje coincide con la especificada o esta vacia
        {
        		// Obtengo el nombre y el telefono
            nombre = (lista[1].trimmed() == "") ? "Desconocido" : lista[1].trimmed();
            telefono = lista[2].trimmed();
            // llamar implica realizar una llamada con tu propio numero empezado en '*'
            if( telefono.left(1) != "*")
            {
                // Busco en la agenda el no, si lo encuentro adjunto el nombre y marco como importante o no
                QModelIndex indice = modelo->index(0, 1, QModelIndex());
                QModelIndexList l = modelo->match(indice, Qt::DisplayRole,telefono);
                // Si no lo encuentro, lo busco empezando por 0
                if(l.isEmpty())
                    l = modelo->match(indice, Qt::DisplayRole,"0" + telefono);
                // Si lo he encontrado
                if(!l.isEmpty())
                {
                    // Obtengo el nombre
                    indice = modelo->index(l.first().row(), 0, QModelIndex());
                    nombre = modelo->data(indice, Qt::DisplayRole).toString();
                    // Obtengo si es importante o no
                    indice = modelo->index(l.first().row(), 2, QModelIndex());
                    importante = (modelo->data(indice, Qt::DisplayRole).toString().trimmed() == marca_imp );
                    encontrado = true;

                }
                // Solo entra si se quieren mostrar todas o si se encuentra en nuestros contactos
                if(encontrado || mostrar_todos)
                {
	                // Si la longitud del telefono es distinta a 5, le aado un 0
  		              telefono = (telefono.length() != 5) ? "0" + telefono : telefono;
                    reg_llam->addEntrada(nombre,telefono,importante);
                    reg_llam->show();
                }

            }
        }
}
Principal::~Principal()
{
    delete ui;
}

void Principal::crearServidor(int puerto)
{
    udpSocket = new QUdpSocket(this);
    // Si no se puede enlazar, abandono el programa
    if( ! udpSocket->bind(puerto, QUdpSocket::DontShareAddress))
    {
        QMessageBox::critical(0, QObject::tr("Error al lanzar la aplicacin"),
                                   QObject::tr("Posibles causas:"
                                               "\n - Hay una instancia de la aplicacin funcionando."
                                               "\n - Hay otra aplicacin escuchando en el mismo puerto."));
         exit(-1);
    }
    // Enlazo el slot de entrada con su manejador
    connect(udpSocket, SIGNAL(readyRead()),this, SLOT(procesarEntrada()));
}

void Principal::crearMenuNotificacion()
{
    // creo el menu
    trayIconMenu = new QMenu();
    trayIconMenu->addAction(callShowAction);
    trayIconMenu->addAction(aboutAction);
    trayIconMenu->addSeparator();
    trayIconMenu->addAction(quitAction);
    // Creo el icono
    trayIcon = new QSystemTrayIcon();
    trayIcon->setContextMenu(trayIconMenu);
    trayIcon->setToolTip(tr("CSIRC * MaViLla"));
    // Capturo la seal de activacion
    connect(trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
                 this, SLOT(iconoActivado(QSystemTrayIcon::ActivationReason)));
    trayIcon->setIcon(icon);
    // Lo muestro
    trayIcon->show();
}

void Principal::closeEvent(QCloseEvent *event)
{
    this->hide();
    //trayIcon->show();
    event->ignore();

}

void Principal::crearAcciones()
 {
 /* Accion quitar */
     quitAction = new QAction(tr("&Salir"), this);
 //    quitAction->setIcon(QIcon(path + "img/salir.png"));
     quitAction->setShortcut(tr("Ctrl+Q"));
     quitAction->setStatusTip(tr("Abandona el porgrama"));
     connect(quitAction, SIGNAL(triggered()),this, SLOT(cerrar()));
/* Accion nuevo */
    newAction = new QAction(tr("&Aadir"), this);
    newAction->setIcon(QIcon(path + "img/nuevo.png"));
    newAction->setShortcut(tr("Ctrl+N"));
    newAction->setStatusTip(tr("Crea una nueva entrada"));
    connect(newAction, SIGNAL(triggered()), this, SLOT(nuevaEntrada()));
/* Accion guardar */
    saveAction = new QAction(tr("&Guardar"), this);
    saveAction->setIcon(QIcon(path + "img/guardar.png"));
    saveAction->setShortcut(tr("Ctrl+S"));
    saveAction->setStatusTip(tr("Guarda la agenda y la configuracin"));
     connect(saveAction, SIGNAL(triggered()),this, SLOT(guardar()));
/* Accion sobre */
    aboutAction = new QAction(tr("Acerca de..."), this);
    aboutAction->setIcon(QIcon(path + "img/sobre.png"));
    aboutAction->setStatusTip(tr("Informacin sobre la aplicacion"));
    connect(aboutAction, SIGNAL(triggered()),this, SLOT(sobre()));
/* Accion borrar */
    deleteAction = new QAction(tr("&Borrar"), this);
    deleteAction->setIcon(QIcon(path + "img/borrar.png"));
    deleteAction->setShortcut(tr("Ctrl+D"));
    deleteAction->setStatusTip(tr("Elimina una entrada"));
    connect(deleteAction, SIGNAL(triggered()), this, SLOT(borrar()));
/* Accion llamar */
    callAction = new QAction(tr("&Llamar"), this);
    callAction->setIcon(QIcon(path + "img/llamar.png"));
    callAction->setShortcut(tr("Ctrl+L"));
    callAction->setStatusTip(tr("Llama a un contacto"));
    connect(callAction, SIGNAL(triggered()),this, SLOT(llamar()));
/* Accion mostrar llamadas */
    callShowAction = new QAction(tr("&Mostrar"), this);
    callShowAction->setIcon(QIcon(path + "img/listado.png"));
    callShowAction->setShortcut(tr("Ctrl+M"));
    callShowAction->setStatusTip(tr("Muestra la lista de llamadas"));
    connect(callShowAction, SIGNAL(triggered()),this, SLOT(mostrarLlamadas()));
/* Accion editar */
    editAction = new QAction(tr("&Editar"), this);
    editAction->setIcon(QIcon(path + "img/editar.png"));
    editAction->setShortcut(tr("Ctrl+E"));
    editAction->setStatusTip(tr("Edita una entrada"));
    connect(editAction, SIGNAL(triggered()),this,SLOT(editar()));
 }

void Principal::cerrar()
{
    if(as_editado)
    {
    		// Si has editado y quieres guardar
        if(this->okToContinue("Guardar","No has guardado los ltimos cambios.\n\n Deseas guardar los cambios ?"))
        {
            guardar();
        }
    }

    exit(0);
}


/* Crea los menus */
void Principal::crearMenus()
{
    menuBar()->setBackgroundRole(QPalette::Shadow);
/* Menu archivo */
    fileMenu = menuBar()->addMenu(tr("&Archivo"));
    fileMenu->addAction(saveAction);
    separatorAction = fileMenu->addSeparator();
    fileMenu->addSeparator();
    fileMenu->addAction(quitAction);

/* Menu editar */
    editMenu = menuBar()->addMenu(tr("&Editar"));
    editMenu->addAction(newAction);
    editMenu->addAction(editAction);
    editMenu->addAction(deleteAction);

/* Menu Ver */
    viewMenu = menuBar()->addMenu(tr("&Ver"));
    viewMenu->addAction(callShowAction);

/* Menu ayuda */
    helpMenu = menuBar()->addMenu(tr("&Ayuda"));
    helpMenu->addAction(aboutAction);

}

/* Crea la barra de herramientas */
void Principal::crearBarraHerramientas()
{
    // Creo la barra de herramientas y le asocio las acciones
    toolBar = addToolBar(tr(""));
    toolBar->setBackgroundRole(QPalette::Shadow);
    toolBar->addAction(newAction);
    toolBar->addAction(editAction);
    toolBar->addAction(deleteAction);
    toolBar->addAction(saveAction);
    toolBar->addSeparator();
    toolBar->addAction(callAction);
    toolBar->addAction(callShowAction);
}

/* Creamos la agenda */
void Principal::crearAgenda()
{
    int nt = 0, nlineas = 0;
    QString errores = "";
    // Creo el modelo de datos con tres columnas
    modelo = new QStandardItemModel(0, 3, this);
    modelo->setHeaderData(0, Qt::Horizontal, QObject::tr("Nombre"));
    modelo->setHeaderData(1, Qt::Horizontal, QObject::tr("Telfono"));
    modelo->setHeaderData(2, Qt::Horizontal, QObject::tr("!"));

    // Abrimos el fichero para leer, si existe lo abre y sino se crea
    QFile archivo(fich_config);
    if ( !archivo.open(QIODevice::ReadOnly | QIODevice::Text))
    {
        archivo.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text);
        archivo.close();
        archivo.open(QIODevice::ReadOnly | QIODevice::Text);
    }
    QTextStream f(&archivo);
    QString nombre, telefono, linea, err;
    bool imp;
    mostrar_todos = true;
    // leo linea a linea y obtengo los datos
    while( !f.atEnd() )
    {
       linea = f.readLine().trimmed();
       nlineas++;
       if( linea != "" )
       { 
       		// Si es la opcion de mostrar todos
           if (linea == cadena_mostrar )
               mostrar_todos = false;
            else if( verificarCadena(linea,err,nombre,telefono,imp) ) // troceamos y verificamos la cadena
            {
                   addEntrada(nombre.trimmed(),telefono.trimmed(),imp);
                   nt++;
            }
            else // Error
            {
                errores += "Linea " + QString::number(nlineas) + ":\n" + err + "\n";
            }
        }
    }

    archivo.close();
    // Mostramos el no de telefonos cargador correctamente
    mostrarMensaje(QString::number(nt) + " telfonos cargados\n", 15);
    ui->checkBox->setChecked(!mostrar_todos);
    // Ponemos los tamaos
    ui->tableView->setModel(modelo);
    ui->tableView->setColumnWidth(0,240);
    ui->tableView->setColumnWidth(1,117);
    ui->tableView->setColumnWidth(2,13);
    // Establecemos la ordenacion
    ui->tableView->setSortingEnabled(true);
    ui->tableView->sortByColumn(0,Qt::AscendingOrder);
    // Reajusto el tamao de las celdas
    for(int i=0; i<modelo->rowCount(); ++i)
        ui->tableView->setRowHeight(i,22);
    // Si ha habido errores, los muestro
    if(errores != "")
    {
        erro->setText(errores);
        erro->show();
    }
    as_editado = false;
}


bool Principal::verificarCadena(QString linea, QString &err, QString &nomb, QString &tel, bool &imp)
{
	// Compruebo mediante expresiones regulares que la cadena tiene el siguiente formato
	// <nombre>,<numero>[*]
    err = nomb = tel = "";
    imp = false;
    QRegExp rxc(",");
    if( linea.contains(rxc) )
    {
    	// Troceo la linea por ','
        QStringList lista = linea.split(",");
        // Si hay suficientes parametros
        switch (lista.count())
        {
        case 1:
            err += "- Falta algn parmetro..(<nombre>,<telefono>[*])\n";
            break;
        default:
            // obtengo el nombre, telefono y si es importante o no
           nomb = lista[0];
           // Concateno el nombre por si hubiera mas de una coma en la linea
           for(int i=1; i<lista.count()-1; ++i)
               nomb += "," + lista[i];
           nomb = nomb.trimmed();
           tel = lista[lista.count()-1].trimmed();
            if( (imp = tel.endsWith(marca_imp)) )
                tel = tel.left(tel.length()-1);
            QRegExp rxt("[0-9]+");
            // Si hay errores, guardo informacion sobre ellos
            if( nomb == "" )
                err += "- Nombre: No puede estar vaco\n";
            if( tel == "" )
                err += "- Telfono: No puede estar vaco\n";
                else if( !rxt.exactMatch(tel) )
                    err += "- Telfono: Debe contener nicamente nmeros\n";
        }
    }
    else
        err += "- Linea mal formada..(<nombre>,<telefono>[*])\n";

    return err == "";
}

/* Aade una entrada a la agenda */
void Principal::addEntrada(const QString &nombre,const QString &telefono, const bool &imp)
 {
	// Crea una entrada nueva en la agenda
    modelo->insertRow(0);
     modelo->setData(modelo->index(0, 0), nombre);
     modelo->setData(modelo->index(0, 1), telefono);
     if( imp )
        modelo->setData(modelo->index(0, 2), marca_imp);
     else
        modelo->setData(modelo->index(0, 2), " ");

 }

/* Llamar al numero seleccionado */
void Principal::llamar()
{
    // Obtenemos la fila y si hay alguna seleccionada
    int fila = this->filaSeleccionada();
    if( fila != -1)
    {
    	// Obtengo el nombre y el telefono de la persona a la que queremos llamar
        QModelIndex indice = modelo->index(fila, 1, QModelIndex()),indice2 = modelo->index(fila, 0, QModelIndex());
        QVariant tel = modelo->data(indice, Qt::DisplayRole);
        QVariant nom = modelo->data(indice2, Qt::DisplayRole);
        // Genero la url y la lanzo
        url = QUrl(url_llamada + tel.toString());
        qnam.get(QNetworkRequest(url));
        // Muestro la informacion de la llamada y la inserto en el registro
        llam_sal->setText("Llamando a:\n" + nom.toString() + "\n" + tel.toString());
		reg_llam->addEntrada(nom.toString(),tel.toString(),false,false);
        llam_sal->show();
    }

}

/* Muestra las llamadas recibidas */
void Principal::mostrarLlamadas()
{
    reg_llam->show();
}

/* Muestra el dialogo de nueva entrada */
void Principal::nuevaEntrada()
{
    ent->resetearEntrada();
    ent->show();
}

/* Informacion sobre la aplicacion */
void Principal::sobre()
{
        QMessageBox::about(this, tr("Acerca de..."),
        tr("<h2 align='center'>") + version + tr("</h2>") +tr(
        "<p align='center'>rea de Servicios Telemticos<br>"
        "CSIRC<br>Universidad de Granada</p>"));
}

/* Guardar la informacion en el fichero */
void Principal::guardar()
{
    // Abrimos el fichero para escribir, si existe se borra y sino se crea
    QFile archivo(fich_config);
    archivo.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text);
    QTextStream f(&archivo);
    int n = modelo->rowCount(), nt=0;
    QModelIndex indice;
    QVariant aux;
    QString nombre, telefono;
    // Si esta la opcion de filtrar
    if( !mostrar_todos )
        f << cadena_mostrar << endl;
    // Guardo los datos de la tabla
    for(int i=0; i<n; ++i, ++nt)
    {
        // Obtengo el nombre
        indice = modelo->index(i, 0, QModelIndex());
        aux = modelo->data(indice, Qt::DisplayRole);
        nombre = aux.toString();
        // Obtengo el telefono
        indice = modelo->index(i, 1, QModelIndex());
        aux = modelo->data(indice, Qt::DisplayRole);
        telefono = aux.toString();
        // Obtengo si es importante o no
        indice = modelo->index(i, 2, QModelIndex());
        aux = modelo->data(indice, Qt::DisplayRole);
        if( aux.toString() == marca_imp)
            telefono += marca_imp;
        // Guardo la linea con el formato adecuado
        f << nombre + "," + telefono << endl;
    }
    // Muestro el no de telefonos guardados
    mostrarMensaje(QString::number(nt) + " telfonos guardados\n", 15);
    archivo.close();
    as_editado = false;
}

/* Borrar un registro */
void Principal::borrar()
{
    // Obtenemos la fila y si hay alguna seleccionada
    int fila = this->filaSeleccionada();
    if( fila != -1)
    {
        bool continuar = this->okToContinue("Borrar"," Desea eliminar la entrada ?");
        // Si queremos realmente borrar la entrada
        if(continuar)
        {
            modelo->removeRow(fila);
            as_editado = true;
        }
    }

}

/* Devuelve la fila selecionada de la tabla */
int Principal::filaSeleccionada()
{
    // Obtenemos una lista de filas seleccionadas y devolvemos la primera
    QItemSelectionModel *selectionModel = ui->tableView->selectionModel();
    QModelIndexList indexes = selectionModel->selectedRows();
    QModelIndex index = indexes.first();
    // Devuelvo la primera fila seleccionada
    foreach (index, indexes) {
        return index.row();
    }
    return -1;
}

/* Muestra un dialogo preguntandonos si queremos aceptar algo no */
bool Principal::okToContinue(QString titulo, QString texto)
{
    QMessageBox msgBox(QMessageBox::Warning,titulo,texto, 0, this);
    msgBox.addButton(tr("Si"), QMessageBox::AcceptRole);
    msgBox.addButton(tr("No"), QMessageBox::RejectRole);
    int r = msgBox.exec();
    // Si aceptamos
    if (r == QMessageBox::AcceptRole)
        return true;
    // Si no
    return false;
}

/* Activacion del icono de la barra de tareas */
void Principal::iconoActivado(QSystemTrayIcon::ActivationReason reason)
 {
     switch (reason) {
     case QSystemTrayIcon::Trigger:
     case QSystemTrayIcon::Unknown:
     		// Escondemos el menu si no clickeamos dos veces o no hacemos click con el boton derecho
         trayIcon->contextMenu()->hide();
         break;
     case QSystemTrayIcon::DoubleClick:
         // Doble click, si la ventana principal esta oculta la muestra y al revs
         if( this->isHidden())
            this->showNormal();
         else
            this->hide();
         break;
     default:
         ;
     }
 }

void Principal::mostrarMensaje(QString texto, int duracion)
{
	// Muestra el mensaje 'texto' en el area de notificacion con una duracion de 'duracion * 1000' s
    trayIcon->showMessage("MaViLla",texto, QSystemTrayIcon::Information, duracion * 1000);
}

void Principal::on_checkBox_stateChanged(int )
{
	// Activa o desactiva el filtro de llamadas entrantes
    mostrar_todos = ! ui->checkBox->isChecked();
}

void Principal::on_lineEdit_returnPressed()
{
    QString cad_a_buscar = ui->lineEdit->text();
    // Busco por nombre
    QModelIndex indice = modelo->index(0, 0, QModelIndex());
    QModelIndexList l = modelo->match(indice, Qt::DisplayRole,cad_a_buscar,-1,Qt::MatchContains | Qt::MatchWrap);
    // Si no encuento nada busco por numero
    if( l.isEmpty() )
    {
        indice = modelo->index(0, 1, QModelIndex());
        l = modelo->match(indice, Qt::DisplayRole,cad_a_buscar,-1,Qt::MatchContains | Qt::MatchWrap);
    }
    // Escondo todas las entradas de la tabla
    for(int i=0; i<modelo->rowCount(); ++i)
        ui->tableView->hideRow(i);
    // Muestro solo aquellas que coincidan con la busqueda
    for(int i=0; i<l.count(); ++i)
       ui->tableView->showRow(l[i].row());
}

/* Muestra el dialogo de edicion */
void Principal::editar()
{
    // Obtenemos la fila y si hay alguna seleccionada
    int fila = this->filaSeleccionada();
    if( fila != -1)
    {
       edi->obtenerEntrada(fila);
       edi->show();
    }

}


/* Crea el menu que aparecera al pinchar con el boton derecho sobre las filas */
void Principal::crearMenusContextuales()
{
        ui->tableView->addAction(newAction);
        ui->tableView->addAction(editAction);
        ui->tableView->addAction(deleteAction);
        ui->tableView->addAction(separatorAction);
        ui->tableView->addAction(callAction);
        ui->tableView->setContextMenuPolicy(Qt::ActionsContextMenu);
}

/* Si se edita algun registro */
void Principal::datosEditados( const QModelIndex & topLeft, const QModelIndex & bottomRight )
{
    as_editado = true;
}


/*
bool Principal::verificarCadena(QString linea, QString &err, QString &nomb, QString &tel, bool &imp)
{
        // Compruebo mediante expresiones regulares que la cadena tiene el siguiente formato
        // <nombre>,<numero>[*]
    err = nomb = tel = "";
    imp = false;
    QRegExp rxc(",");
    if( linea.contains(rxc) )
    {
        // Troceo la linea por ','
        QStringList lista = linea.split(",");
        // Si hay suficientes parametros
        switch (lista.count())
        {
        case 1:
            err += "- Falta algn parmetro..(<nombre>,<telefono>[*])\n";
            break;
        default:
                        // obtengo el nombre, telefono y si es importante o no
            nomb = lista[0].trimmed();
            tel = lista[1].trimmed();
            if( (imp = tel.endsWith(marca_imp)) )
                tel = tel.left(tel.length()-1);
            QRegExp rxt("[0-9]+");
            // Si hay errores, guardo informacion sobre ellos
            if( nomb == "" )
                err += "- Nombre: No puede estar vaco\n";
            if( tel == "" )
                err += "- Telfono: No puede estar vaco\n";
                else if( !rxt.exactMatch(tel) )
                    err += "- Telfono: Debe contener nicamente nmeros\n";
        }
    }
    else
        err += "- Linea mal formada..(<nombre>,<telefono>[*])\n";

    return err == "";
}

*/
